==> jmb.address-0.1.tar.gz: jmb.address-0.1/jmb/address/models.py <==
# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jmb.l10n.models import Country

#######################################
# INDIRIZZO FINALITA                  #
#######################################
class AddressScope (DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField (
        unique = True,
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    is_invoice_address = models.BooleanField(
        default=False,
        verbose_name=_('Invoice Address'),
        help_text = _("If this address scope is an invoice address")
    )
    is_shipping_address = models.BooleanField(
        default=False,
        verbose_name=_('Shipping Address'),
        help_text = _("If this address scope is a shipping address")
    )

    class Meta:
        verbose_name = _("address scope")
        verbose_name_plural = _("address scopes")

    def __unicode__(self):
        return unicode(self.name)

    def _get_default_country(self):
        return Country.objects.get(iso2_code='IT')

###############################
# INDIRIZZO                   #
###############################
class Address (DateModel, UserModel, StatusModel, OrderedModel):
    address_scopes = models.ManyToManyField (
        AddressScope,
        db_index = True,
        verbose_name = _("address scopes"),
    )
    address_type = models.IntegerField (
        default=7,
        choices = settings.ADDRESS_ADDRESS_TYPE_CHOICES,
        db_index = True,
        verbose_name = _("address type"),
        blank = True, null = True
    )
    name = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    number = models.CharField (
        max_length = 20,
        blank = True, null = True,
        verbose_name = _("number"),
        db_column = "anumber" # number in alcuni db (come oracle) e' una parola
        # riservata, quindi mettiamo come colonna del db
        # anumber per avere la piena compatibilita
    )
    crossed = models.CharField (
        max_length = 5,
        blank = True, null = True,
        verbose_name = _("crossed"),
    )
    scale = models.CharField (
        max_length = 5,
        blank = True, null = True,
        verbose_name = _("scale"),
    )
    floor = models.CharField (
        max_length = 3,
        blank = True, null = True,
        verbose_name = _("floor"),
    )
    zip_code = models.CharField (
        max_length = 20,
        db_index = True,
        verbose_name = _("zip code"),
        blank = True, null = True,
    )
    locality = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("locality"),
        blank = True, null = True,
    )
    ## FIXME da sistemare (rifNazione, rifProvincia)
    province = models.CharField (
        max_length = 2,
        db_index = True,
        verbose_name = _("province"),
        blank = True, null = True,
    )
    country = models.ForeignKey (
        Country,
        db_index = True,
        default = 108, # id of Italy Country
        verbose_name = _("country"),
    )
    post_office = models.CharField (
        max_length = 10,
        blank = True, null = True,
        verbose_name = _("post office"),
    )

    def get_scopes(self):
        list_scopes = ""
        scopes = self.address_scopes.all()
        names = [ scope.name for  scope in scopes ]
        return ", ".join(names)
    get_scopes.short_description = _("scopes")

    def get_organizations(self):
        list_organizations = ""
        organizations = self.organization_set.all()
        names = [ organization.name for organization in organizations ]
        return ", ".join(names)
    get_organizations.short_description = _("organizations")

    def get_gmaps_address(self):
        return "%(address_type)s %(name)s, %(number)s, %(cap)s, %(locality)s" % {
            'address_type': self.get_address_type_display() or '',
            'name': self.name,
            'number': self.number,
            'locality': self.locality,
            'cap': self.zip_code or ''}
    gmaps_address = property(get_gmaps_address)

    class Meta:
        verbose_name = _("address")
        verbose_name_plural = _("addresses")
        abstract = True

    def __unicode__(self):
        return u"%(address_type)s %(name)s, %(number)s... - %(locality)s (%(province)s) - %(country)s" % {
            'address_type': self.get_address_type_display(),
            'name': self.name, 'number': self.number,
            'locality': self.locality, 'province': self.province,
            'country': self.country
        }

==> jmb.address-0.2.tar.gz: jmb.address-0.2/jmb/address/models.py <==
# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.core.exceptions import ObjectDoesNotExist

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jmb.l10n.models import Country

#######################################
# INDIRIZZO FINALITA                  #
#######################################
class AddressScope (DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField (
        unique = True,
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    is_invoice_address = models.BooleanField(
        default=False,
        verbose_name=_('Invoice Address'),
        help_text = _("If this address scope is an invoice address")
    )
    is_shipping_address = models.BooleanField(
        default=False,
        verbose_name=_('Shipping Address'),
        help_text = _("If this address scope is a shipping address")
    )

    class Meta:
        verbose_name = _("address scope")
        verbose_name_plural = _("address scopes")

    def __unicode__(self):
        return unicode(self.name)

    def _get_default_country(self):
        return Country.objects.get(iso2_code='IT')

###############################
# INDIRIZZO                   #
###############################
class Address (DateModel, UserModel, StatusModel, OrderedModel):

    def get_default_country():
	try:
            return Country.objects.get(iso2_code='IT')
	except ObjectDoesNotExist:
	    return False

    address_scopes = models.ManyToManyField (
        AddressScope,
        db_index = True,
        verbose_name = _("address scopes"),
    )
    address_type = models.IntegerField (
        default=7,
        choices = settings.ADDRESS_ADDRESS_TYPE_CHOICES,
        db_index = True,
        verbose_name = _("address type"),
        blank = True, null = True
    )
    name = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    number = models.CharField (
        max_length = 20,
        blank = True, null = True,
        verbose_name = _("number"),
        db_column = "anumber" # number in alcuni db (come oracle) e' una parola
        # riservata, quindi mettiamo come colonna del db
        # anumber per avere la piena compatibilita
    )
    crossed = models.CharField (
        max_length = 5,
        blank = True, null = True,
        verbose_name = _("crossed"),
    )
    scale = models.CharField (
        max_length = 5,
        blank = True, null = True,
        verbose_name = _("scale"),
    )
    floor = models.CharField (
        max_length = 3,
        blank = True, null = True,
        verbose_name = _("floor"),
    )
    zip_code = models.CharField (
        max_length = 20,
        db_index = True,
        verbose_name = _("zip code"),
        blank = True, null = True,
    )
    locality = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("locality"),
        blank = True, null = True,
    )
    ## FIXME da sistemare (rifNazione, rifProvincia)
    province = models.CharField (
        max_length = 2,
        db_index = True,
        verbose_name = _("province"),
        blank = True, null = True,
    )
    country = models.ForeignKey (
        Country,
        db_index = True,
        default = get_default_country, # id of Italy Country
        verbose_name = _("country"),
    )
    post_office = models.CharField (
        max_length = 10,
        blank = True, null = True,
        verbose_name = _("post office"),
    )

    def get_scopes(self):
        list_scopes = ""
        scopes = self.address_scopes.all()
        names = [ scope.name for  scope in scopes ]
        return ", ".join(names)
    get_scopes.short_description = _("scopes")

    def get_organizations(self):
        list_organizations = ""
        organizations = self.organization_set.all()
        names = [ organization.name for organization in organizations ]
        return ", ".join(names)
    get_organizations.short_description = _("organizations")

    def get_gmaps_address(self):
        return "%(address_type)s %(name)s, %(number)s, %(cap)s, %(locality)s" % {
            'address_type': self.get_address_type_display() or '',
            'name': self.name,
            'number': self.number,
            'locality': self.locality,
            'cap': self.zip_code or ''}
    gmaps_address = property(get_gmaps_address)

    class Meta:
        verbose_name = _("address")
        verbose_name_plural = _("addresses")
        abstract = True

    def __unicode__(self):
        return u"%(address_type)s %(name)s, %(number)s... - %(locality)s (%(province)s) - %(country)s" % {
            'address_type': self.get_address_type_display(),
            'name': self.name, 'number': self.number,
            'locality': self.locality, 'province': self.province,
            'country': self.country
        }
